#### Building instructions.
#
### Overview of rebuild options:
#
# --without userland		: Build without the userland-package (default: with it)
# --without modules		: Build without the kernel-module-package (default: with it)
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different fedora-kernel.  
#
### Examples:
#
## To rebuild whole package for the running kernel:
#
# rpmbuild -ba THIS.SPEC --target "$(uname -m)"
# 
## To rebuild only userland-package: 
#
# rpmbuild -ba THIS.SPEC --without modules
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against a kernel where /lib/modules/$(uname -r)/build points
##  to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.

%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}
%define modpath   kernel/drivers/net/wireless/madfiwi/

Name:		madwifi
Epoch:		0
Version:	0.9.6.0
Release:	1
Summary: A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
License:	proprietary
Group: System Environment/Kernel
URL: http://madwifi.org/
Source0:	%{name}-%{version}-r1417.tar.bz2
#Patch0:		madwifi-avoid-kernelpathcheck.diff
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: /usr/bin/uudecode
ExclusiveArch:  %{ix86} x86_64

Requires:	kernel-module-madwifi >= %{epoch}:%{version}

%description
madfifi is the Multiband Atheros Driver for WiFi, a linux device driver for 
802.11a/b/g universal NIC cards - either Cardbus, PCI or MiniPCI - that use
Atheros chipsets (ar5210, ar5211, ar5212).

This package contains diagnostic tools you can use to get information
about your madwifi Atheros wireless connections. You do not need this
package to make a madwifi connection.

%package -n kernel-module-madwifi-%{kernel}
Summary:        Kernel module for Atheros 802.11 wireless devices ar5210,ar5211 or ar5212.
Group:          System Environment/Kernel

Provides:	kernel-module-madwifi = %{epoch}:%{version}-%{release}

Requires(post):   modutils
Requires(postun): modutils
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
%endif
%if 0%{!?_without_modules:1}
%if 0%{!?ksrc:1}
BuildRequires:  sharutils
BuildRequires:  kernel-devel-%{_target_cpu} = %{kernel}
%endif
%endif


%description -n kernel-module-madwifi-%{kernel}
This package contains the Multiband Atheros Driver for WiFi, a linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).


%prep
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
%setup -q
#%if 0%{!?_without_userland:1}
#%ifarch i386
# Avoid the check for kernel-patch and kernel-config if we only build userland -- there is no kernel-devel for i386
#%patch0 -b .patch0
#%endif
#%endif

%build
export TOOLPREFIX=%{_bindir}/
%ifarch %ix86
export TARGET=i386-elf
%endif
%ifarch x86_64
export TARGET=x86_64-elf
%endif

%if 0%{!?_without_modules:1}
make KERNELPATH="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" KERNELRELEASE=%{kernel}
%endif # build_modules

%if 0%{!?_without_userland:1}
cd ./tools
make KERNELPATH="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" KERNELRELEASE=%{kernel} all
cd ..
%endif # {build_userland}


%install
%if 0%{!?_without_modules:1}
rm -rf $RPM_BUILD_ROOT
make KERNELPATH="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" KERNELRELEASE=%{kernel} DESTDIR=$RPM_BUILD_ROOT MODULEPATH=/lib/modules/%{kernel}/%{modpath}/ install 
chmod 0755 $RPM_BUILD_ROOT/lib/modules/%{kernel}/%{modpath}/*
%endif # build_modules

%if 0%{!?_without_userland:1}
cd ./tools
mkdir -p $RPM_BUILD_ROOT%{_bindir}
make KERNELPATH="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" KERNELRELEASE=%{kernel} DESTDIR=$RPM_BUILD_ROOT BINDIR=%{_bindir} install
cd ..
%endif # {build_userland}


%clean
rm -rf $RPM_BUILD_ROOT


%post -n kernel-module-madwifi-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif

 
%postun -n kernel-module-madwifi-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%if 0%{!?_without_userland:1}
%files
%defattr(-,root,root,-)
%doc COPYRIGHT README
%attr(0755,root,root) %_bindir/*
%endif # {build_userland}

%if 0%{!?_without_modules:1}
%files -n kernel-module-madwifi-%{kernel}
%defattr(-,root,root,-)
%dir /lib/modules/%{kernel}/%{modpath}
%attr(0644,root,root) /lib/modules/%{kernel}/%{modpath}/*
%endif # build_modules


%changelog
* Tue Apr 18 2006 Troy Dawson <dawson@fnal.gov>
- Hacked together Axel Thimm and livna's spec files
